//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // plib.h, config bits, constants, funcs for startup and UART

#define VOLTS_PER_COUNT (3.3/1024)
#define CORE_TICK_TIME 25    // nanoseconds between core ticks
#define SAMPLE_TIME 10       // 10 core timer ticks = 250 ns
#define DELAY_TICKS 20000000 // delay 1/2 sec, 20 M core ticks, between messages

int main(void) {
  unsigned int sample14, sample15, elapsed, finishtime;
  char msg[100];

  NU32_Startup(); // cache on, min flash wait, interrupts on, LED/button init, UART init

  AD1PCFG = 0x3FFF;         // bits 14 and 15 are 0, so AN14 and AN15 are AN inputs
  AD1CON3bits.ADCS = 2;     // ADC clock period is Tad = 2 * (ADCS+1) * Tpb
  AD1CON1bits.ADON = 1;     // turn on A/D converter

  while (1) {
    WriteCoreTimer(0);
    AD1CHSbits.CH0SA = 14;  // connect pin AN14 to MUXA for sampling
    AD1CON1bits.SAMP = 1;   // start sampling
    elapsed = ReadCoreTimer();
    finishtime = elapsed + SAMPLE_TIME;
    while (ReadCoreTimer() < finishtime); // sample for more than 200 ns
    AD1CON1bits.SAMP = 0;   // stop sampling and start converting
    while (!AD1CON1bits.DONE); // wait for the conversion process to finish
    sample14 = ADC1BUF0;    // read the buffer with the result

    AD1CHSbits.CH0SA = 15;  // connect pin AN15 to MUXA for sampling
    AD1CON1bits.SAMP = 1;   // start sampling
    elapsed = ReadCoreTimer();
    finishtime = elapsed + SAMPLE_TIME;
    while (ReadCoreTimer() < finishtime); // sample for more than 200 ns
    AD1CON1bits.SAMP = 0;   // stop sampling and start converting
    while (!AD1CON1bits.DONE); // wait for the conversion process to finish
    sample15 = ADC1BUF0;    // read the buffer with the result
    elapsed = ReadCoreTimer();

    // send the results over serial
    sprintf(msg, "Time elapsed: %5u ns  AN14: %4u (%5.3f volts)  \
AN15: %4u (%5.3f volts) \r\n",elapsed*CORE_TICK_TIME, sample14,
	    sample14*VOLTS_PER_COUNT, sample15, sample15*VOLTS_PER_COUNT);
    NU32_WriteUART1(msg);
    WriteCoreTimer(0);      // make the messages less frantic!
    while(ReadCoreTimer()<DELAY_TICKS);
  }
}

